from mediawiki import DisambiguationError

from wikifaces.downloader import WikiFace

if __name__ == '__main__':
    wf = WikiFace()
    cats = ['David Wagner']
    pgs = []
    for cat in cats:
        try:
            pgs = wf.wikidata.page(title=cat, auto_suggest=False)
        except DisambiguationError as e:
            pages = wf.wikidata.opensearch(cat)
            pages = [page for page in pages if page[0] != cat]
            pgs = [page[0] for page in pages if ':' not in page[0]]
    print(pgs)


from setuptools import setup

with open('README.md', 'r') as f:
    long_description = f.read()

setup(
    name='wikifaces',
    version='1.0.7',
    description='A downloader for named images containing faces from Wiki servers.',
    long_description=long_description,
    long_description_content_type="text/markdown",
    url='https://github.com/tford9/Wiki-Faces-Downloader',
    author='Trenton W. Ford & Ruiting Shao',
    author_email='tford5@nd.edu',
    license='MIT License',
    packages=['wikifaces'],
    install_requires=['requests',
                      'facenet-pytorch',
                      'pymediawiki',
                      'tqdm',
                      'numpy',
                      'pillow',
                      'opencv-python',
                      ],

    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: MIT License',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python :: 3',
    ],
)
